@@ -1,29 +1,32 @@
 """wheel tests"""
 
-from distutils.sysconfig import get_config_var
-from distutils.util import get_platform
+from __future__ import annotations
+
 import contextlib
-import pathlib
-import stat
 import glob
 import inspect
 import os
+import pathlib
 import shutil
+import stat
 import subprocess
 import sys
 import zipfile
+from typing import Any
 
 import pytest
 from jaraco import path
-
-from pkg_resources import Distribution, PathMetadata, PY_MAJOR
-from packaging.utils import canonicalize_name
 from packaging.tags import parse_tag
+from packaging.utils import canonicalize_name
+
+from pkg_resources import PY_MAJOR, Distribution, PathMetadata
 from setuptools.wheel import Wheel
 
 from .contexts import tempdir
 from .textwrap import DALS
 
+from distutils.sysconfig import get_config_var
+from distutils.util import get_platform
 
 WHEEL_INFO_TESTS = (
     ('invalid.whl', ValueError),
@@ -176,7 +179,10 @@ class Record:
         return '%s(**%r)' % (self._id, self._fields)
 
 
-WHEEL_INSTALL_TESTS = (
+# Using Any to avoid possible type union issues later in test
+# making a TypedDict is not worth in a test and anonymous/inline TypedDict are experimental
+# https://github.com/python/mypy/issues/9884
+WHEEL_INSTALL_TESTS: tuple[dict[str, Any], ...] = (
     dict(
         id='basic',
         file_defs={'foo': {'__init__.py': ''}},
@@ -547,7 +553,7 @@ WHEEL_INSTALL_TESTS = (
 @pytest.mark.parametrize(
     'params',
     WHEEL_INSTALL_TESTS,
-    ids=list(params['id'] for params in WHEEL_INSTALL_TESTS),
+    ids=[params['id'] for params in WHEEL_INSTALL_TESTS],
 )
 def test_wheel_install(params):
     project_name = params.get('name', 'foo')
